@@ -1,3 +1,4 @@
+import logging
 import unittest
 
 from tortoise import Tortoise
@@ -18,6 +19,8 @@ class BasicTestCase(unittest.IsolatedAsyncioTestCase):
     async def asyncSetUp(self) -> None:
         await super().asyncSetUp()
 
+        logging.basicConfig(level=logging.DEBUG)
+
         await Tortoise.init(config=self.config)
 
         await Tortoise.generate_schemas(safe=True)
